const webpack = require('webpack')
const {EnvironmentPlugin} = require('webpack')
const config = require('./webpack.base')

config.plugins = config.plugins.concat(
  new EnvironmentPlugin({
    NODE_ENV: 'production',
  }),
  new webpack.optimize.UglifyJsPlugin({})
)

module.exports = config
