# {{ name }}

a project generated by [tifa](https://github.com/wddwycc/tifa)


## setup

```
$ npm install
```

```
$ virtualenv venv -p <python_version>
$ . venv/bin/activate
$ pip install -r requirements.txt
```

## run webpack dev server

```
npm run dev
```

## run flask server

Add your flask base settings in `conf/base_settings.py`. Then run

```
python manage.py run
```

Enjoy coding~
