JS_LIB_VERS = {
    "vue": "^2.4.4",

    "babel-core": "^6.26.0",
    "babel-loader": "^7.1.2",
    "babel-preset-env": "^1.6.0",
    "css-loader": "^0.28.7",
    "extract-text-webpack-plugin": "^3.0.0",
    "html-webpack-plugin": "^2.30.1",
    "style-loader": "^0.18.2",
    "vue-loader": "^13.0.4",
    "vue-template-compiler": "^2.4.4",
    "webpack": "^3.6.0",
    "webpack-dev-server": "^2.8.2",
}

WEBPACK_MODE_DISABLE = False
WEBPACK_MODE_CLASSIC = 'classic'
WEBPACK_MODE_SEPARATE = 'separate'
WEBPACK_MODE_RADICAL = 'radical'
